@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2014,2015 Hayaki Saito
+ * Copyright (c) 2014-2018 Hayaki Saito
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy of
  * this software and associated documentation files (the "Software"), to deal in
@@ -30,7 +30,7 @@
 # define SIXELAPI
 #endif
 
-#define LIBSIXEL_VERSION "1.7.3"
+#define LIBSIXEL_VERSION "1.8.2"
 #define LIBSIXEL_ABI_VERSION "1:6:0"
 
 #define SIXEL_OUTPUT_PACKET_SIZE     16384
@@ -89,6 +89,8 @@ typedef int SIXELSTATUS;
 #define SIXEL_DIFFUSE_JAJUNI      0x4  /* diffuse with Jarvis, Judice & Ninke method */
 #define SIXEL_DIFFUSE_STUCKI      0x5  /* diffuse with Stucki's method */
 #define SIXEL_DIFFUSE_BURKES      0x6  /* diffuse with Burkes' method */
+#define SIXEL_DIFFUSE_A_DITHER    0x7  /* positionally stable arithmetic dither */
+#define SIXEL_DIFFUSE_X_DITHER    0x8  /* positionally stable arithmetic xor based dither */
 
 /* quality modes */
 #define SIXEL_QUALITY_AUTO        0x0  /* choose quality mode automatically */
@@ -99,7 +101,7 @@ typedef int SIXELSTATUS;
 
 /* built-in dither */
 #define SIXEL_BUILTIN_MONO_DARK   0x0  /* monochrome terminal with dark background */
-#define SIXEL_BUILTIN_MONO_LIGHT  0x1  /* monochrome terminal with dark background */
+#define SIXEL_BUILTIN_MONO_LIGHT  0x1  /* monochrome terminal with light background */
 #define SIXEL_BUILTIN_XTERM16     0x2  /* xterm 16color */
 #define SIXEL_BUILTIN_XTERM256    0x3  /* xterm 256color */
 #define SIXEL_BUILTIN_VT340_MONO  0x4  /* vt340 monochrome */
@@ -210,6 +212,10 @@ typedef int SIXELSTATUS;
                                                     jajuni   -> Jarvis, Judice & Ninke
                                                     stucki   -> Stucki's method
                                                     burkes   -> Burkes' method
+                                                    a_dither -> positionally stable
+                                                                arithmetic dither
+                                                    a_dither -> positionally stable
+                                                                arithmetic xor based dither
                                                 */
 #define SIXEL_OPTFLAG_FIND_LARGEST      ('f')  /* -f FINDTYPE, --find-largest=FINDTYPE:
                                                   choose method for finding the largest
@@ -354,7 +360,7 @@ typedef int SIXELSTATUS;
 #define SIXEL_OPTFLAG_PENETRATE         ('P')  /* -P, --penetrate:
                                                   penetrate GNU Screen using DCS
                                                   pass-through sequence */
-#define SIXEL_OPTFLAG_PIPE_MODE         ('D')  /* -D, --pipe-mode:
+#define SIXEL_OPTFLAG_PIPE_MODE         ('D')  /* -D, --pipe-mode: (deprecated)
                                                   read source images from stdin continuously */
 #define SIXEL_OPTFLAG_VERBOSE           ('v')  /* -v, --verbose: show debugging info */
 #define SIXEL_OPTFLAG_VERSION           ('V')  /* -V, --version: show version and license info */
@@ -364,7 +370,7 @@ typedef int SIXELSTATUS;
 /* output character size */
 enum characterSize {
     CSIZE_7BIT = 0,  /* 7bit character */
-    CSIZE_8BIT = 1,  /* 8bit character */
+    CSIZE_8BIT = 1   /* 8bit character */
 };
 
 /* method for finding the largest dimension for splitting,
@@ -394,7 +400,9 @@ enum methodForDiffuse {
     DIFFUSE_FS       = 3, /* diffuse with Floyd-Steinberg method */
     DIFFUSE_JAJUNI   = 4, /* diffuse with Jarvis, Judice & Ninke method */
     DIFFUSE_STUCKI   = 5, /* diffuse with Stucki's method */
-    DIFFUSE_BURKES   = 6  /* diffuse with Burkes' method */
+    DIFFUSE_BURKES   = 6, /* diffuse with Burkes' method */
+    DIFFUSE_A_DITHER = 7, /* positionally stable arithmetic dither */
+    DIFFUSE_X_DITHER = 8  /* positionally stable arithmetic xor based dither */
 };
 
 /* quality modes */
@@ -403,7 +411,7 @@ enum qualityMode {
     QUALITY_HIGH      = 1, /* high quality palette construction */
     QUALITY_LOW       = 2, /* low quality palette construction */
     QUALITY_FULL      = 3, /* full quality palette construction */
-    QUALITY_HIGHCOLOR = 4, /* high color */
+    QUALITY_HIGHCOLOR = 4  /* high color */
 };
 
 /* built-in dither */
@@ -413,14 +421,14 @@ enum builtinDither {
     BUILTIN_XTERM16     = 2, /* xterm 16color */
     BUILTIN_XTERM256    = 3, /* xterm 256color */
     BUILTIN_VT340_MONO  = 4, /* vt340 monochrome */
-    BUILTIN_VT340_COLOR = 5, /* vt340 color */
+    BUILTIN_VT340_COLOR = 5  /* vt340 color */
 };
 
 /* offset value of enum pixelFormat */
 enum formatType {
     FORMATTYPE_COLOR     = 0,
     FORMATTYPE_GRAYSCALE = 1 << 6,
-    FORMATTYPE_PALETTE   = 1 << 7,
+    FORMATTYPE_PALETTE   = 1 << 7
 };
 
 /* pixelformat type of input image
@@ -443,21 +451,21 @@ enum pixelFormat {
     PIXELFORMAT_PAL1     = FORMATTYPE_PALETTE   | 0x00, /* 1bpp palette */
     PIXELFORMAT_PAL2     = FORMATTYPE_PALETTE   | 0x01, /* 2bpp palette */
     PIXELFORMAT_PAL4     = FORMATTYPE_PALETTE   | 0x02, /* 4bpp palette */
-    PIXELFORMAT_PAL8     = FORMATTYPE_PALETTE   | 0x03, /* 8bpp palette */
+    PIXELFORMAT_PAL8     = FORMATTYPE_PALETTE   | 0x03  /* 8bpp palette */
 };
 
 /* palette type */
 enum paletteType {
     PALETTETYPE_AUTO = 0,     /* choose palette type automatically */
     PALETTETYPE_HLS  = 1,     /* HLS colorspace */
-    PALETTETYPE_RGB  = 2,     /* RGB colorspace */
+    PALETTETYPE_RGB  = 2      /* RGB colorspace */
 };
 
 /* policies of SIXEL encoding */
 enum encodePolicy {
     ENCODEPOLICY_AUTO = 0,    /* choose encoding policy automatically */
     ENCODEPOLICY_FAST = 1,    /* encode as fast as possible */
-    ENCODEPOLICY_SIZE = 2,    /* encode to as small sixel sequence as possible */
+    ENCODEPOLICY_SIZE = 2     /* encode to as small sixel sequence as possible */
 };
 
 /* method for re-sampling */
@@ -471,7 +479,7 @@ enum methodForResampling {
     RES_BICUBIC  = 6,  /* Use bicubic filter */
     RES_LANCZOS2 = 7,  /* Use lanczos-2 filter */
     RES_LANCZOS3 = 8,  /* Use lanczos-3 filter */
-    RES_LANCZOS4 = 9,  /* Use lanczos-4 filter */
+    RES_LANCZOS4 = 9   /* Use lanczos-4 filter */
 };
 #endif
 
@@ -870,14 +878,14 @@ enum imageFormat {
     FORMAT_PNM   =  8, /* read only */
     FORMAT_GD2   =  9, /* read only with --with-gd configure option */
     FORMAT_PSD   = 10, /* read only */
-    FORMAT_HDR   = 11, /* read only */
+    FORMAT_HDR   = 11  /* read only */
 };
 
 /* loop mode */
 enum loopControl {
     LOOP_AUTO    = 0,  /* honer the setting of GIF header */
     LOOP_FORCE   = 1,  /* always enable loop */
-    LOOP_DISABLE = 2,  /* always disable loop */
+    LOOP_DISABLE = 2   /* always disable loop */
 };
 #endif
 
